import React from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { queryTable } from '@/utils/request';
import { ProTable } from '@ant-design/pro-components';
import { Button, message, Popconfirm } from 'antd';
import { getMessageList, setMessageReaded } from '@/services/message';

const queryMessage = queryTable(getMessageList);

export default (props) => {
  const actionRef = React.useRef();

  const setReaded = (id) => {
    setMessageReaded(id).then(() => {
      actionRef.current.reset();
    })
  }

  const columns = [
    {
      title: '时间',
      dataIndex: 'createDate',
      valueType: 'date',
      search: false,
      width: 160,
    },
    {
      title: '时间',
      dataIndex: 'createDate',
      valueType: 'dateRange',
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            startDate: value[0],
            endDate: value[1],
          };
        },
      },
    },
    {
      title: '内容',
      dataIndex: 'message',
    },
    {
      title: '状态',
      dataIndex: 'isReaded',
      search: false,
      width: 120,
      valueEnum: {
        true: {
          text: '已读',
          status: 'Processing',
        },
        false: {
          text: '未读',
          status: 'Error',
        },
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 200,
      render: (_, record) => {
        const doUrl = record.targetType === 'store' ?
        `/stock/list?id=${record.targetId}` : undefined;

        return [
          <Button
            key={1}
            type="link"
            disabled={record.isReaded}
            onClick={() => setReaded(record.id)}
          >
            设为已读
          </Button>,
          <Link
            key={2}
            to={doUrl}
          >
            去处理
          </Link>,
        ]
      },
    },
  ]

  return (
    <ProTable
      rowKey="id"
      actionRef={actionRef}
      request={queryMessage}
      columns={columns}
    />
  )
}
