import { addRegulation, getRegulationList } from "@/services/regulation";
import {
  PageContainer,
  ProForm,
  ProFormTextArea,
} from "@ant-design/pro-components";
import { Card, Col, Button, Row, Space, Typography } from "antd";
import { useNavigate, useSearchParams } from "react-router-dom";
import { useEffect, useRef, useState } from "react";
import Wangeditor from "@/components/Wangeditor";

const { Title } = Typography;
export default (props) => {
  const [searchParams, setSearchParams] = useSearchParams();
  const id = searchParams.get("id");
  const [data, setData] = useState({});
  const [isEdit, setIsEdit] = useState(false);
  const [loading, setLoading] = useState(false);
  const formRef = useRef();
  const navigate = useNavigate();

  useEffect(() => {
    getRegulationData();
  }, []);

  const getRegulationData = () => {
    setLoading(true);
    getRegulationList({ type: `station` }).then((res) => {
      setData(res.records[0]||{});
      setLoading(false);
      // formRef.current.setFieldsValue(res.records[0]);
      // console.log('tt', res)
    });
  };
  useEffect(() => {
    if (isEdit) {
      formRef.current.setFieldsValue(data);
    }
  }, [isEdit]);

  const onFinish = async (values) => {
    //添加,修改
    addRegulation({ ...values, id: data?.id, type: "station" }).then((res) => {
      // message.success('成功');
      getRegulationData();
      setIsEdit(false);
    });
    return false;
  };

  return (
    <PageContainer>
      <Card
        title={
          <Button type="primary" onClick={() => setIsEdit(!isEdit)}>
            {isEdit ? "取消编辑" : "编辑"}
          </Button>
        }
        loading={loading}
      >
        {!isEdit ? (
          <>
            {/* <Title level={2} style={{ marginBottom: "2em" }}>
              {data.title}
            </Title> */}
            <div dangerouslySetInnerHTML={{ __html: data?.detail }}></div>
          </>
        ) : (
          <ProForm
            formRef={formRef}
            layout={"horizontal"}
            labelCol={{ span: 4 }}
            wrapperCol={{ span: 16 }}
            onFinish={onFinish}
            submitter={{
              searchConfig: {
                resetText: "返回",
              },
              resetButtonProps: {
                style: {
                  // 隐藏重置按钮
                  display: "none",
                },
              },
              // onReset: () => navigate(-1),
              render: (props, doms) => {
                return (
                  <Row>
                    <Col span={8} offset={6}>
                      <Space>{doms}</Space>
                    </Col>
                  </Row>
                );
              },
            }}
          >
            <ProForm.Item
              name="detail"
              label="发布内容"
              placeholder="请输入发布内容"
              rules={[{ required: true, message: "请输入发布内容" }]}
            >
              <Wangeditor></Wangeditor>
            </ProForm.Item>
          </ProForm>
        )}
      </Card>
    </PageContainer>
  );
};
